@@ -1,13 +1,13 @@
 ;;; otpp.el --- One tab per project, with unique names -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2024-2025  Abdelhak Bougouffa
+;; Copyright (C) 2024-2026  Abdelhak Bougouffa
 
 ;; Author: Abdelhak Bougouffa (rot13 "nobhtbhssn@srqbencebwrpg.bet")
 ;; URL: https://github.com/abougouffa/one-tab-per-project
 ;; Created: July 07, 2024
 ;; Modified: June 15, 2025
-;; Package-Version: 20250909.2023
-;; Package-Revision: fb8e72b92401
+;; Package-Version: 20260129.811
+;; Package-Revision: 3bb181034b3b
 ;; Package-Requires: ((emacs "28.1") (compat "29.1"))
 ;; Keywords: convenience
 ;; SPDX-License-Identifier: GPL-3.0
@@ -211,6 +211,18 @@ non-nil if we should allow the tab creation."
   :group 'otpp
   :version "2.0.0")
 
+(defcustom otpp-find-file-integration nil
+  "When non-nil, if a file is opened, switch to its project and tab.
+Create the tab if the project isn't already open."
+  :type 'boolean
+  :group 'otpp
+  :set (lambda (symbol value)
+         (let ((was-enabled (bound-and-true-p otpp-mode)))
+           (when was-enabled (otpp-mode -1))
+           (set-default symbol value)
+           (when was-enabled (otpp-mode 1))))
+  :version "3.4.0")
+
 (defcustom otpp-override-commands
   '(;; project
     project-find-file project-find-dir project-kill-buffers project-switch-to-buffer
@@ -671,6 +683,25 @@ Calls ORIG-FN based on ARGS."
     (funcall fn buffer)))
 
 
+;;; Advices for the integration with `find-file'
+
+(defun otpp--find-file-a (orig-fn &rest args)
+  "Advice `find-file'.
+
+The behavior is like this:
+
+When opening a file that belongs to another project, switch to that
+project (switchs to its tab). If the project isn't open, open it and
+create the project's tab.
+
+Calls ORIG-FN with ARGS."
+  (when-let* ((proj-curr (project-current nil (file-name-directory (car args)))))
+    (message (file-name-directory (car args)))
+    (let ((project-switch-commands #'ignore))
+      (project-switch-project (project-root proj-curr))))
+  (apply orig-fn args))
+
+
 ;;; OTPP modes
 
 ;;;###autoload
@@ -685,10 +716,13 @@ Calls ORIG-FN based on ARGS."
         (advice-remove fn advice-fn))))
   (if otpp-mode
       (progn
+        (when otpp-find-file-integration
+          (advice-add 'find-file :around #'otpp--find-file-a))
         (advice-add 'kill-buffer :around #'otpp--bury-on-kill-buffer-in-multiple-tabs-a)
         ;; Rename the first tab to default name if needed
         (otpp--set-default-tab-name)
         (add-hook 'server-after-make-frame-hook #'otpp--set-default-tab-name))
+    (advice-remove 'find-file #'otpp--find-file-a)
     (advice-remove 'kill-buffer #'otpp--bury-on-kill-buffer-in-multiple-tabs-a)
     (remove-hook 'server-after-make-frame-hook #'otpp--set-default-tab-name)))
 
